If you discover a security vulnerability in this project, please follow the steps below to report it.

### For "non-critical" issues

- **Alternative A:**
Create a GitHub issue for the vulnerability. Avoid putting sensitive information in the issue.

- **Alternative B:**
Send an email to the projects maintainer describing the issue.

### For "critical" and time sensitive issues

Phone the Equinor helpdesk:

- Norway (+47) 51 999 222
- US/Canada (+1) 713 878 6970
